#include <Application.h>
#include <Messenger.h>
#include <Message.h>
#include <Roster.h>
#include <Window.h>
#include <View.h>
#include <MenuBar.h>
#include <Menu.h>
#include <MenuItem.h>

const uint32 MENU_NIGHT_ONE				= 'MNn1';
const uint32 MENU_NIGHT_TWO				= 'MNn2';
const uint32 MENU_NIGHT_THREE			= 'MNn3';
const uint32 MENU_NIGHT_FOUR			= 'MNn4';
const uint32 MENU_NIGHT_FIVE			= 'MNn5';
const uint32 MENU_NIGHT_SIX				= 'MNn6';
const uint32 MENU_NIGHT_SEVEN			= 'MNn7';
const uint32 MENU_NIGHT_EIGHT			= 'MNn8';

const char *APP_NAME					= "Virtual Menorah";

int lights;

class HView : public BView
{
	public:
		HView(BRect frame);
		virtual void Draw(BRect updateRect);
		
};

HView::HView(BRect frame):BView(frame, "HanukkahView", 
					B_FOLLOW_ALL_SIDES, B_WILL_DRAW)
{
// Nothing happens here
}


void HView::Draw(BRect updateRect)
{
	SetPenSize(5);
	
	StrokeLine(BPoint(175,50),BPoint(175,300));
	
	StrokeLine(BPoint(150,300),BPoint(200,300));
	StrokeArc(BPoint(200,275),25,25,180,90);
	StrokeArc(BPoint(150,275),25,25,270,90);
	
	StrokeArc(BPoint(175,70),30,30,180,180);
	StrokeArc(BPoint(175,70),60,60,180,180);
	StrokeArc(BPoint(175,70),90,90,180,180);
	StrokeArc(BPoint(175,70),120,120,180,180);

	MovePenTo(BPoint(20,320));
	SetFontSize(20);
	DrawString("Happy Hanukkah");
	
	SetHighColor(255,178,1,100);
	StrokeLine(BPoint(175,53),BPoint(175,35));
	SetHighColor(255,255,1,255);
	StrokeArc(BPoint(175,50),5,5,189,270);
	
	switch (lights)
	{
		case 8:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(55,73),BPoint(55,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(55,70),5,5,189,270);
		}
		case 7:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(85,73),BPoint(85,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(85,70),5,5,189,270);
		}
		case 6:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(115,73),BPoint(115,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(115,70),5,5,189,270);
		}
		case 5:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(145,73),BPoint(145,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(145,70),5,5,189,270);
		}
		case 4:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(205,73),BPoint(205,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(205,70),5,5,189,270);
		}
		case 3:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(235,73),BPoint(235,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(235,70),5,5,189,270);
		}
		case 2:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(265,73),BPoint(265,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(265,70),5,5,189,270);
		}
		case 1:{
			SetHighColor(255,178,1,100);
			StrokeLine(BPoint(295,73),BPoint(295,55));
			SetHighColor(255,255,1,255);
			StrokeArc(BPoint(295,70),5,5,189,270);
		}
		break;
	default:
		//I need a bit bucket
		break;
	}
	
}


class HWindow : public BWindow
{
	public:
		HWindow(BRect frame);
		virtual bool QuitRequested();
		virtual void MessageReceived(BMessage *message);
		
	private:
		BMenuBar *menubar;
		HView *hview;
};

HWindow::HWindow(BRect frame) : BWindow(frame, APP_NAME, B_TITLED_WINDOW,
									B_NOT_RESIZABLE|B_NOT_ZOOMABLE)
{
//Building menu
	BRect r;
	BMenu *menu;
	
	r = Bounds();
	menubar = new BMenuBar(r, "menu_bar");
	AddChild(menubar);
	
	menu = new BMenu("Night");
	menu->AddItem(new BMenuItem("1", new BMessage(MENU_NIGHT_ONE)));
	menu->AddItem(new BMenuItem("2", new BMessage(MENU_NIGHT_TWO)));
	menu->AddItem(new BMenuItem("3", new BMessage(MENU_NIGHT_THREE)));
	menu->AddItem(new BMenuItem("4", new BMessage(MENU_NIGHT_FOUR)));
	menu->AddItem(new BMenuItem("5", new BMessage(MENU_NIGHT_FIVE)));
	menu->AddItem(new BMenuItem("6", new BMessage(MENU_NIGHT_SIX)));
	menu->AddItem(new BMenuItem("7", new BMessage(MENU_NIGHT_SEVEN)));
	menu->AddItem(new BMenuItem("8", new BMessage(MENU_NIGHT_EIGHT)));
	menubar->AddItem(menu);
	
//end building menu
	
	r.top = menubar->Bounds().bottom+1;
	AddChild(hview = new HView(r));
	Show();
}

void HWindow::MessageReceived(BMessage *message)
{
//nothing yet
	switch(message->what)
	{
		case MENU_NIGHT_ONE:
		{
			lights = 1;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_TWO:
		{
			lights = 2;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_THREE:
		{
			lights = 3;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_FOUR:
		{
			lights = 4;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_FIVE:
		{
			lights = 5;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_SIX:
		{
			lights = 6;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_SEVEN:
		{
			lights = 7;
			hview->Invalidate();
		}
		break;
		
		case MENU_NIGHT_EIGHT:
		{
			lights = 8;
			hview->Invalidate();
		}
		break;
		
	default:
		BWindow::MessageReceived(message);
		break;
	}
}

bool HWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return true;
}

class HanukkahApp : public BApplication
{
	public:
		HanukkahApp();
		//virtual void MessageReceived(BMessage *message);
		
	private:
		HWindow *theWindow;
};

HanukkahApp::HanukkahApp():BApplication("application/x-vnd.AGibson-Virtual_Hanukkah")
{
	BRect windowRect;
	
	windowRect.Set(50,50,400,400);
	theWindow = new HWindow(windowRect);
}

int main(void)
{
	lights = 0;
	HanukkahApp *theApp;
	theApp = new(HanukkahApp);
	theApp->Run();
	delete theApp;
}